==> org.apache.sling.models.api-1.3.8-sources.jar: org/apache/sling/models/annotations/injectorspecific/ResourcePath.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.sling.models.annotations.injectorspecific;

import static java.lang.annotation.ElementType.FIELD;
import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.ElementType.PARAMETER;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import org.apache.sling.models.annotations.Source;
import org.apache.sling.models.spi.injectorspecific.InjectAnnotation;

/**
 * Annotation to be used on either methods, fields or constructor parameters to let Sling Models inject a
 * resource by path(s). The path may be either in the path/paths attribute or in a value map property with the given name.
 */
@Target({ METHOD, FIELD, PARAMETER })
@Retention(RUNTIME)
@InjectAnnotation
@Source("resource-path")
public @interface ResourcePath {

    /**
     * Specifies the path of the resource. If not provided, the path is derived from the property name.
     */
    public String path() default "";
    
    /**
     * Specifies more than one path for the resource. If not provided, a single path is derived from the property name.
     */
    public String[] paths() default {};

    /**
     * Specifies the name of the property containing the resource path. If empty or not set, then the name
     * is derived from the method or field.
     */
    public String name() default "";

    /**
     * If set to true, the model can be instantiated even if there is no request attribute
     * with the given name found.
     * Default = false.
     * @deprecated Use {@link #injectionStrategy} instead.
     */
    @Deprecated
    public boolean optional() default false;

    /**
     * if set to REQUIRED injection is mandatory, if set to OPTIONAL injection is optional, in case of DEFAULT 
     * the standard annotations ({@link org.apache.sling.models.annotations.Optional}, {@link org.apache.sling.models.annotations.Required}) are used.
     * If even those are not available the default injection strategy defined on the {@link org.apache.sling.models.annotations.Model} applies.
     * Default value = DEFAULT.
     */
    public InjectionStrategy injectionStrategy() default InjectionStrategy.DEFAULT;

}

==> org.apache.sling.models.api-1.5.0-sources.jar: org/apache/sling/models/annotations/injectorspecific/ResourcePath.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.sling.models.annotations.injectorspecific;

import static java.lang.annotation.ElementType.FIELD;
import static java.lang.annotation.ElementType.METHOD;
import static java.lang.annotation.ElementType.PARAMETER;
import static java.lang.annotation.RetentionPolicy.RUNTIME;

import java.lang.annotation.Retention;
import java.lang.annotation.Target;

import org.apache.sling.models.annotations.Source;
import org.apache.sling.models.spi.injectorspecific.InjectAnnotation;

/**
 * Annotation to be used on either methods, fields or constructor parameters to let Sling Models inject a
 * resource by path(s). The path may be either in the path/paths attribute or in a value map property with the given name.
 */
@Target({ METHOD, FIELD, PARAMETER })
@Retention(RUNTIME)
@InjectAnnotation
@Source("resource-path")
public @interface ResourcePath {

    /**
     * Specifies the path of the resource. If not provided, the path is derived from the property name.
     * @return Path
     */
    public String path() default "";

    /**
     * Specifies more than one path for the resource. If not provided, a single path is derived from the property name.
     * @return Paths
     */
    public String[] paths() default {};

    /**
     * Specifies the name of the property containing the resource path. If empty or not set, then the name
     * is derived from the method or field.
     * @return Name
     */
    public String name() default "";

    /**
     * If set to true, the model can be instantiated even if there is no request attribute
     * with the given name found.
     * Default = false.
     * @return Optional
     * @deprecated Use {@link #injectionStrategy} instead.
     */
    @Deprecated
    public boolean optional() default false;

    /**
     * Specifies the injection strategy applied to an annotated element:
     * <ul>
     * <li>If set to {@link InjectionStrategy#REQUIRED}, injection is mandatory.</li>
     * <li>If set to {@link InjectionStrategy#OPTIONAL}, injection is optional.</li>
     * <li>If set to {@link InjectionStrategy#DEFAULT} (default), the default injection strategy defined on the
     * {@link org.apache.sling.models.annotations.Model} applies.</li>
     * </ul>
     * WARNING: Injection strategy is ignored if either {@link org.apache.sling.models.annotations.Optional}
     * or {@link org.apache.sling.models.annotations.Required} is applied on the same element.
     * @return Injection strategy
     */
    public InjectionStrategy injectionStrategy() default InjectionStrategy.DEFAULT;

}
